==> libofx-0.10.7.tgz: share/doc/libofx/html/files_dup.js <==
var files_dup =
[
    [ "cmdline.c", "cmdline_8c_source.html", null ],
    [ "cmdline.h", "cmdline_8h.html", "cmdline_8h" ],
    [ "config.h", "config_8h_source.html", null ],
    [ "context.cpp", "context_8cpp_source.html", null ],
    [ "context.hh", "context_8hh_source.html", null ],
    [ "file_preproc.cpp", "file__preproc_8cpp.html", "file__preproc_8cpp" ],
    [ "file_preproc.hh", "file__preproc_8hh.html", "file__preproc_8hh" ],
    [ "inc/libofx.h", "inc_2libofx_8h.html", "inc_2libofx_8h" ],
    [ "libofx-0.10.7/inc/libofx.h", "libofx-0_810_87_2inc_2libofx_8h.html", "libofx-0_810_87_2inc_2libofx_8h" ],
    [ "messages.cpp", "messages_8cpp.html", "messages_8cpp" ],
    [ "messages.hh", "messages_8hh.html", "messages_8hh" ],
    [ "ofc_sgml.cpp", "ofc__sgml_8cpp.html", "ofc__sgml_8cpp" ],
    [ "ofc_sgml.hh", "ofc__sgml_8hh.html", "ofc__sgml_8hh" ],
    [ "ofx_aggregate.hh", "ofx__aggregate_8hh.html", [
      [ "OfxAggregate", "classOfxAggregate.html", "classOfxAggregate" ]
    ] ],
    [ "ofx_container_account.cpp", "ofx__container__account_8cpp.html", "ofx__container__account_8cpp" ],
    [ "ofx_container_generic.cpp", "ofx__container__generic_8cpp.html", "ofx__container__generic_8cpp" ],
    [ "ofx_container_main.cpp", "ofx__container__main_8cpp.html", null ],
    [ "ofx_container_position.cpp", "ofx__container__position_8cpp.html", "ofx__container__position_8cpp" ],
    [ "ofx_container_security.cpp", "ofx__container__security_8cpp.html", "ofx__container__security_8cpp" ],
    [ "ofx_container_statement.cpp", "ofx__container__statement_8cpp.html", "ofx__container__statement_8cpp" ],
    [ "ofx_container_transaction.cpp", "ofx__container__transaction_8cpp.html", "ofx__container__transaction_8cpp" ],
    [ "ofx_containers.hh", "ofx__containers_8hh.html", [
      [ "OfxGenericContainer", "classOfxGenericContainer.html", "classOfxGenericContainer" ],
      [ "OfxDummyContainer", "classOfxDummyContainer.html", "classOfxDummyContainer" ],
      [ "OfxInv401kContainer", "classOfxInv401kContainer.html", "classOfxInv401kContainer" ],
      [ "OfxPushUpContainer", "classOfxPushUpContainer.html", "classOfxPushUpContainer" ],
      [ "OfxStatusContainer", "classOfxStatusContainer.html", "classOfxStatusContainer" ],
      [ "OfxBalanceContainer", "classOfxBalanceContainer.html", "classOfxBalanceContainer" ],
      [ "OfxStatementContainer", "classOfxStatementContainer.html", "classOfxStatementContainer" ],
      [ "OfxAccountContainer", "classOfxAccountContainer.html", "classOfxAccountContainer" ],
      [ "OfxSecurityContainer", "classOfxSecurityContainer.html", "classOfxSecurityContainer" ],
      [ "OfxPositionContainer", "classOfxPositionContainer.html", "classOfxPositionContainer" ],
      [ "OfxTransactionContainer", "classOfxTransactionContainer.html", "classOfxTransactionContainer" ],
      [ "OfxBankTransactionContainer", "classOfxBankTransactionContainer.html", "classOfxBankTransactionContainer" ],
      [ "OfxInvestmentTransactionContainer", "classOfxInvestmentTransactionContainer.html", "classOfxInvestmentTransactionContainer" ],
      [ "OfxMainContainer", "classOfxMainContainer.html", "classOfxMainContainer" ]
    ] ],
    [ "ofx_containers_misc.cpp", "ofx__containers__misc_8cpp.html", "ofx__containers__misc_8cpp" ],
    [ "ofx_error_msg.hh", "ofx__error__msg_8hh.html", "ofx__error__msg_8hh" ],
    [ "ofx_preproc.cpp", "ofx__preproc_8cpp.html", "ofx__preproc_8cpp" ],
    [ "ofx_preproc.hh", "ofx__preproc_8hh.html", "ofx__preproc_8hh" ],
    [ "ofx_request.cpp", "ofx__request_8cpp.html", "ofx__request_8cpp" ],
    [ "ofx_request.hh", "ofx__request_8hh.html", "ofx__request_8hh" ],
    [ "ofx_request_accountinfo.cpp", "ofx__request__accountinfo_8cpp.html", "ofx__request__accountinfo_8cpp" ],
    [ "ofx_request_accountinfo.hh", "ofx__request__accountinfo_8hh.html", [
      [ "OfxAccountInfoRequest", "classOfxAccountInfoRequest.html", "classOfxAccountInfoRequest" ]
    ] ],
    [ "ofx_request_statement.cpp", "ofx__request__statement_8cpp.html", "ofx__request__statement_8cpp" ],
    [ "ofx_request_statement.hh", "ofx__request__statement_8hh.html", [
      [ "OfxStatementRequest", "classOfxStatementRequest.html", "classOfxStatementRequest" ],
      [ "OfxPaymentRequest", "classOfxPaymentRequest.html", "classOfxPaymentRequest" ]
    ] ],
    [ "ofx_sgml.cpp", "ofx__sgml_8cpp.html", "ofx__sgml_8cpp" ],
    [ "ofx_sgml.hh", "ofx__sgml_8hh.html", "ofx__sgml_8hh" ],
    [ "ofx_utilities.cpp", "ofx__utilities_8cpp.html", "ofx__utilities_8cpp" ],
    [ "ofx_utilities.hh", "ofx__utilities_8hh.html", "ofx__utilities_8hh" ],
    [ "tree.hh", "tree_8hh_source.html", null ],
    [ "win32.cpp", "win32_8cpp_source.html", null ],
    [ "win32.hh", "win32_8hh_source.html", null ]
];

==> libofx-0.10.9p3.tgz: share/doc/libofx/html/files_dup.js <==
var files_dup =
[
    [ "ofxconnect/cmdline.c", "ofxconnect_2cmdline_8c_source.html", null ],
    [ "ofxdump/cmdline.c", "ofxdump_2cmdline_8c_source.html", null ],
    [ "ofxconnect/cmdline.h", "ofxconnect_2cmdline_8h.html", "ofxconnect_2cmdline_8h" ],
    [ "ofxdump/cmdline.h", "ofxdump_2cmdline_8h.html", "ofxdump_2cmdline_8h" ],
    [ "config.h", "config_8h_source.html", null ],
    [ "context.cpp", "context_8cpp_source.html", null ],
    [ "context.hh", "context_8hh_source.html", null ],
    [ "file_preproc.cpp", "file__preproc_8cpp.html", "file__preproc_8cpp" ],
    [ "file_preproc.hh", "file__preproc_8hh.html", "file__preproc_8hh" ],
    [ "inc/libofx.h", "inc_2libofx_8h.html", "inc_2libofx_8h" ],
    [ "libofx-0.10.8/inc/libofx.h", "libofx-0_810_88_2inc_2libofx_8h.html", "libofx-0_810_88_2inc_2libofx_8h" ],
    [ "messages.cpp", "messages_8cpp.html", "messages_8cpp" ],
    [ "messages.hh", "messages_8hh.html", "messages_8hh" ],
    [ "ofc_sgml.cpp", "ofc__sgml_8cpp.html", "ofc__sgml_8cpp" ],
    [ "ofc_sgml.hh", "ofc__sgml_8hh.html", "ofc__sgml_8hh" ],
    [ "ofx_aggregate.hh", "ofx__aggregate_8hh.html", [
      [ "OfxAggregate", "classOfxAggregate.html", "classOfxAggregate" ]
    ] ],
    [ "ofx_container_account.cpp", "ofx__container__account_8cpp.html", "ofx__container__account_8cpp" ],
    [ "ofx_container_generic.cpp", "ofx__container__generic_8cpp.html", "ofx__container__generic_8cpp" ],
    [ "ofx_container_main.cpp", "ofx__container__main_8cpp.html", null ],
    [ "ofx_container_position.cpp", "ofx__container__position_8cpp.html", "ofx__container__position_8cpp" ],
    [ "ofx_container_security.cpp", "ofx__container__security_8cpp.html", "ofx__container__security_8cpp" ],
    [ "ofx_container_statement.cpp", "ofx__container__statement_8cpp.html", "ofx__container__statement_8cpp" ],
    [ "ofx_container_transaction.cpp", "ofx__container__transaction_8cpp.html", "ofx__container__transaction_8cpp" ],
    [ "ofx_containers.hh", "ofx__containers_8hh.html", [
      [ "OfxGenericContainer", "classOfxGenericContainer.html", "classOfxGenericContainer" ],
      [ "OfxDummyContainer", "classOfxDummyContainer.html", "classOfxDummyContainer" ],
      [ "OfxInv401kContainer", "classOfxInv401kContainer.html", "classOfxInv401kContainer" ],
      [ "OfxPushUpContainer", "classOfxPushUpContainer.html", "classOfxPushUpContainer" ],
      [ "OfxStatusContainer", "classOfxStatusContainer.html", "classOfxStatusContainer" ],
      [ "OfxBalanceContainer", "classOfxBalanceContainer.html", "classOfxBalanceContainer" ],
      [ "OfxStatementContainer", "classOfxStatementContainer.html", "classOfxStatementContainer" ],
      [ "OfxAccountContainer", "classOfxAccountContainer.html", "classOfxAccountContainer" ],
      [ "OfxSecurityContainer", "classOfxSecurityContainer.html", "classOfxSecurityContainer" ],
      [ "OfxPositionContainer", "classOfxPositionContainer.html", "classOfxPositionContainer" ],
      [ "OfxTransactionContainer", "classOfxTransactionContainer.html", "classOfxTransactionContainer" ],
      [ "OfxBankTransactionContainer", "classOfxBankTransactionContainer.html", "classOfxBankTransactionContainer" ],
      [ "OfxInvestmentTransactionContainer", "classOfxInvestmentTransactionContainer.html", "classOfxInvestmentTransactionContainer" ],
      [ "OfxMainContainer", "classOfxMainContainer.html", "classOfxMainContainer" ]
    ] ],
    [ "ofx_containers_misc.cpp", "ofx__containers__misc_8cpp.html", "ofx__containers__misc_8cpp" ],
    [ "ofx_error_msg.hh", "ofx__error__msg_8hh.html", "ofx__error__msg_8hh" ],
    [ "ofx_preproc.cpp", "ofx__preproc_8cpp.html", "ofx__preproc_8cpp" ],
    [ "ofx_preproc.hh", "ofx__preproc_8hh.html", "ofx__preproc_8hh" ],
    [ "ofx_request.cpp", "ofx__request_8cpp.html", "ofx__request_8cpp" ],
    [ "ofx_request.hh", "ofx__request_8hh.html", "ofx__request_8hh" ],
    [ "ofx_request_accountinfo.cpp", "ofx__request__accountinfo_8cpp.html", "ofx__request__accountinfo_8cpp" ],
    [ "ofx_request_accountinfo.hh", "ofx__request__accountinfo_8hh.html", [
      [ "OfxAccountInfoRequest", "classOfxAccountInfoRequest.html", "classOfxAccountInfoRequest" ]
    ] ],
    [ "ofx_request_statement.cpp", "ofx__request__statement_8cpp.html", "ofx__request__statement_8cpp" ],
    [ "ofx_request_statement.hh", "ofx__request__statement_8hh.html", [
      [ "OfxStatementRequest", "classOfxStatementRequest.html", "classOfxStatementRequest" ],
      [ "OfxPaymentRequest", "classOfxPaymentRequest.html", "classOfxPaymentRequest" ]
    ] ],
    [ "ofx_sgml.cpp", "ofx__sgml_8cpp.html", "ofx__sgml_8cpp" ],
    [ "ofx_sgml.hh", "ofx__sgml_8hh.html", "ofx__sgml_8hh" ],
    [ "ofx_utilities.cpp", "ofx__utilities_8cpp.html", "ofx__utilities_8cpp" ],
    [ "ofx_utilities.hh", "ofx__utilities_8hh.html", "ofx__utilities_8hh" ],
    [ "tree.hh", "tree_8hh_source.html", null ],
    [ "win32.cpp", "win32_8cpp_source.html", null ],
    [ "win32.hh", "win32_8hh_source.html", null ]
];
